@@ -5,4 +5,4 @@ A python client for the Expensify API
 __version__ = "0.1.0"
 __author__ = "Alex Lazich"
 
-from client import ExpensifyClient
\ No newline at end of file
+from .client import ExpensifyClient
\ No newline at end of file
